/* properties.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;
typedef struct _BoxesPropertiesPrivate BoxesPropertiesPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;

#define BOXES_TYPE_MINI_GRAPH (boxes_mini_graph_get_type ())
#define BOXES_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph))
#define BOXES_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))
#define BOXES_IS_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MINI_GRAPH))
#define BOXES_IS_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MINI_GRAPH))
#define BOXES_MINI_GRAPH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))

typedef struct _BoxesMiniGraph BoxesMiniGraph;
typedef struct _BoxesMiniGraphClass BoxesMiniGraphClass;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_PROPERTIES_TYPE_PAGE_WIDGET (boxes_properties_page_widget_get_type ())
#define BOXES_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidget))
#define BOXES_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))
#define BOXES_PROPERTIES_IS_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET))
#define BOXES_PROPERTIES_IS_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_PROPERTIES_TYPE_PAGE_WIDGET))
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))

typedef struct _BoxesPropertiesPageWidget BoxesPropertiesPageWidget;
typedef struct _BoxesPropertiesPageWidgetClass BoxesPropertiesPageWidgetClass;
typedef struct _Block48Data Block48Data;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))
typedef struct _BoxesPropertiesPageWidgetPrivate BoxesPropertiesPageWidgetPrivate;
typedef struct _Block49Data Block49Data;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;
typedef struct _Block50Data Block50Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesProperties {
	GtkStack parent_instance;
	BoxesPropertiesPrivate * priv;
};

struct _BoxesPropertiesClass {
	GtkStackClass parent_class;
};

struct _BoxesPropertiesPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	gulong stats_id;
	gboolean restore_fullscreen;
	BoxesPropertiesPage _page;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesSidebar {
	GtkRevealer parent_instance;
	BoxesSidebarPrivate * priv;
	GtkImage* screenshot;
	GtkListStore* props_listmodel;
	GtkTreeSelection* props_selection;
	GtkButton* shutdown_button;
	BoxesMiniGraph* cpu_graph;
	BoxesMiniGraph* io_graph;
	BoxesMiniGraph* net_graph;
};

struct _BoxesSidebarClass {
	GtkRevealerClass parent_class;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _Block48Data {
	int _ref_count_;
	BoxesProperties* self;
	BoxesPropertiesPageWidget* page;
};

struct _BoxesPropertiesPageWidget {
	GtkBox parent_instance;
	BoxesPropertiesPageWidgetPrivate * priv;
	gboolean empty;
};

struct _BoxesPropertiesPageWidgetClass {
	GtkBoxClass parent_class;
};

struct _Block49Data {
	int _ref_count_;
	BoxesProperties* self;
	BoxesLibvirtMachine* libvirt_machine;
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _Block50Data {
	int _ref_count_;
	BoxesProperties* self;
	BoxesMachine* machine;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationCancelFunc) (void* user_data);
struct _BoxesPropertiesPageWidgetPrivate {
	GtkGrid* grid;
	GList* properties;
};


static gpointer boxes_properties_parent_class = NULL;
extern BoxesAppWindow* boxes_app_window;
extern BoxesApp* boxes_app_app;
static gpointer boxes_properties_page_widget_parent_class = NULL;
static BoxesUIIface* boxes_properties_boxes_ui_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES, BoxesPropertiesPrivate))
enum  {
	BOXES_PROPERTIES_DUMMY_PROPERTY,
	BOXES_PROPERTIES_PREVIOUS_UI_STATE,
	BOXES_PROPERTIES_UI_STATE,
	BOXES_PROPERTIES_PAGE
};
static void boxes_properties_list_append (BoxesProperties* self, GtkListStore* listmodel, const gchar* label, gboolean visible);
static void boxes_properties_populate (BoxesProperties* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_mini_graph_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_machine_is_running (BoxesMachine* self);
static GType boxes_properties_page_widget_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static Block48Data* block48_data_ref (Block48Data* _data48_);
static void block48_data_unref (void * _userdata_);
static BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine);
static BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine);
static void _____lambda154_ (Block48Data* _data48_);
static void ______lambda154__boxes_properties_page_widget_refresh_properties (BoxesPropertiesPageWidget* _sender, gpointer self);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void boxes_properties_setup_ui (BoxesProperties* self);
static void boxes_properties_ui_state_changed (BoxesProperties* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
gboolean boxes_app_window_get_fullscreened (BoxesAppWindow* self);
void boxes_app_window_set_fullscreened (BoxesAppWindow* self, gboolean value);
static Block49Data* block49_data_ref (Block49Data* _data49_);
static void block49_data_unref (void * _userdata_);
static void ____lambda155_ (Block49Data* _data49_);
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
void boxes_mini_graph_set_points (BoxesMiniGraph* self, gdouble* value, int value_length1);
static void _____lambda155__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self);
static Block50Data* block50_data_ref (Block50Data* _data50_);
static void block50_data_unref (void * _userdata_);
static gboolean boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self);
gboolean boxes_machine_is_on (BoxesMachine* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static void _____lambda156_ (Block50Data* _data50_);
void boxes_machine_restart (BoxesMachine* self);
static void ______lambda156__boxes_notification_ok_func (gpointer self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
BoxesProperties* boxes_properties_new (void);
BoxesProperties* boxes_properties_construct (GType object_type);
BoxesPropertiesPage boxes_properties_get_page (BoxesProperties* self);
void boxes_properties_set_page (BoxesProperties* self, BoxesPropertiesPage value);
static GObject * boxes_properties_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_properties_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetPrivate))
enum  {
	BOXES_PROPERTIES_PAGE_WIDGET_DUMMY_PROPERTY
};
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
const gchar* boxes_property_get_description (BoxesProperty* self);
GtkWidget* boxes_property_get_widget (BoxesProperty* self);
GtkWidget* boxes_property_get_extra_widget (BoxesProperty* self);
static void _____lambda153_ (BoxesPropertiesPageWidget* self);
static void ______lambda153__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self);
void boxes_property_flush (BoxesProperty* self);
gboolean boxes_property_get_reboot_required (BoxesProperty* self);
static void boxes_properties_page_widget_finalize (GObject* obj);
static void boxes_properties_finalize (GObject* obj);
static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

static const gchar* BOXES_PROPERTIES_page_names[4] = {"login", "system", "display", "devices"};

GType boxes_properties_page_get_type (void) {
	static volatile gsize boxes_properties_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_PROPERTIES_PAGE_LOGIN, "BOXES_PROPERTIES_PAGE_LOGIN", "login"}, {BOXES_PROPERTIES_PAGE_SYSTEM, "BOXES_PROPERTIES_PAGE_SYSTEM", "system"}, {BOXES_PROPERTIES_PAGE_DISPLAY, "BOXES_PROPERTIES_PAGE_DISPLAY", "display"}, {BOXES_PROPERTIES_PAGE_DEVICES, "BOXES_PROPERTIES_PAGE_DEVICES", "devices"}, {BOXES_PROPERTIES_PAGE_LAST, "BOXES_PROPERTIES_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_properties_page_type_id;
		boxes_properties_page_type_id = g_enum_register_static ("BoxesPropertiesPage", values);
		g_once_init_leave (&boxes_properties_page_type_id__volatile, boxes_properties_page_type_id);
	}
	return boxes_properties_page_type_id__volatile;
}


static void boxes_properties_list_append (BoxesProperties* self, GtkListStore* listmodel, const gchar* label, gboolean visible) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkListStore* _tmp2_ = NULL;
	GtkTreeIter _tmp3_ = {0};
	const gchar* _tmp4_ = NULL;
	GtkListStore* _tmp5_ = NULL;
	GtkTreeIter _tmp6_ = {0};
	gboolean _tmp7_ = FALSE;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (listmodel != NULL);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (label != NULL);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = listmodel;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_append (_tmp0_, &_tmp1_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iter = _tmp1_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = listmodel;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = iter;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = label;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_set (_tmp2_, &_tmp3_, 0, _tmp4_, -1);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = listmodel;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = iter;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = visible;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_set (_tmp5_, &_tmp6_, 1, _tmp7_, -1);
#line 605 "properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 612 "properties.c"
}


static Block48Data* block48_data_ref (Block48Data* _data48_) {
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_atomic_int_inc (&_data48_->_ref_count_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return _data48_;
#line 621 "properties.c"
}


static void block48_data_unref (void * _userdata_) {
	Block48Data* _data48_;
	_data48_ = (Block48Data*) _userdata_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (g_atomic_int_dec_and_test (&_data48_->_ref_count_)) {
#line 630 "properties.c"
		BoxesProperties* self;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self = _data48_->self;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (_data48_->page);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (self);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_slice_free (Block48Data, _data48_);
#line 640 "properties.c"
	}
}


static void _____lambda154_ (Block48Data* _data48_) {
	BoxesProperties* self;
	BoxesPropertiesPageWidget* current_page = NULL;
	BoxesPropertiesPageWidget* _tmp0_ = NULL;
	BoxesPropertiesPageWidget* _tmp1_ = NULL;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesSidebar* _tmp4_ = NULL;
	GtkTreeSelection* _tmp5_ = NULL;
	BoxesPropertiesPageWidget* _tmp6_ = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = _data48_->self;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = _data48_->page;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	current_page = _tmp1_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_populate (self);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = gtk_tree_path_new_from_indices (current_page, -1);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	path = _tmp2_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = boxes_app_window;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = _tmp3_->sidebar;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = _tmp4_->props_selection;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_selection_select_path (_tmp5_, path);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = _g_object_ref0 (current_page);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (_data48_->page);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_data48_->page = _tmp6_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_gtk_tree_path_free0 (path);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (current_page);
#line 688 "properties.c"
}


static void ______lambda154__boxes_properties_page_widget_refresh_properties (BoxesPropertiesPageWidget* _sender, gpointer self) {
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda154_ (self);
#line 695 "properties.c"
}


static void boxes_properties_populate (BoxesProperties* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesSidebar* _tmp1_ = NULL;
	GtkListStore* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	BoxesMachine* machine = NULL;
	BoxesApp* _tmp5_ = NULL;
	BoxesCollectionItem* _tmp6_ = NULL;
	BoxesMachine* _tmp7_ = NULL;
	BoxesLibvirtMachine* libvirt_machine = NULL;
	BoxesApp* _tmp8_ = NULL;
	BoxesCollectionItem* _tmp9_ = NULL;
	BoxesLibvirtMachine* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	BoxesLibvirtMachine* _tmp12_ = NULL;
	BoxesAppWindow* _tmp15_ = NULL;
	BoxesSidebar* _tmp16_ = NULL;
	GtkButton* _tmp17_ = NULL;
	BoxesMachine* _tmp18_ = NULL;
	BoxesPropertiesPage current_page = 0;
	BoxesLibvirtMachine* _tmp44_ = NULL;
	GtkTreePath* path = NULL;
	BoxesPropertiesPage _tmp48_ = 0;
	GtkTreePath* _tmp49_ = NULL;
	BoxesAppWindow* _tmp50_ = NULL;
	BoxesSidebar* _tmp51_ = NULL;
	GtkTreeSelection* _tmp52_ = NULL;
	GtkTreePath* _tmp53_ = NULL;
	BoxesPropertiesPage _tmp54_ = 0;
	const gchar* _tmp55_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = boxes_app_window;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _tmp0_->sidebar;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = _tmp1_->props_listmodel;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_clear (_tmp2_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = gtk_container_get_children ((GtkContainer*) self);
#line 741 "properties.c"
	{
		GList* page_collection = NULL;
		GList* page_it = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		page_collection = _tmp3_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		for (page_it = page_collection; page_it != NULL; page_it = page_it->next) {
#line 749 "properties.c"
			GtkWidget* page = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			page = (GtkWidget*) page_it->data;
#line 753 "properties.c"
			{
				GtkWidget* _tmp4_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp4_ = page;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				gtk_container_remove ((GtkContainer*) self, _tmp4_);
#line 760 "properties.c"
			}
		}
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_list_free0 (page_collection);
#line 765 "properties.c"
	}
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = boxes_app_app;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = _tmp5_->current_item;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp6_) : NULL);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	machine = _tmp7_;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = boxes_app_app;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = _tmp8_->current_item;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp9_) : NULL);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	libvirt_machine = _tmp10_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp12_ = libvirt_machine;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp12_ != NULL) {
#line 787 "properties.c"
		BoxesLibvirtMachine* _tmp13_ = NULL;
		gboolean _tmp14_ = FALSE;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp13_ = libvirt_machine;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp14_ = boxes_machine_is_running ((BoxesMachine*) _tmp13_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp11_ = _tmp14_;
#line 796 "properties.c"
	} else {
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp11_ = FALSE;
#line 800 "properties.c"
	}
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp15_ = boxes_app_window;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp16_ = _tmp15_->sidebar;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp17_ = _tmp16_->shutdown_button;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp17_, _tmp11_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp18_ = machine;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp18_ == NULL) {
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (libvirt_machine);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (machine);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		return;
#line 820 "properties.c"
	}
	{
		gint i = 0;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		i = 0;
#line 826 "properties.c"
		{
			gboolean _tmp19_ = FALSE;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp19_ = TRUE;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			while (TRUE) {
#line 833 "properties.c"
				Block48Data* _data48_;
				gint _tmp21_ = 0;
				gint _tmp22_ = 0;
				BoxesMachine* _tmp23_ = NULL;
				BoxesPropertiesPageWidget* _tmp24_ = NULL;
				BoxesPropertiesPageWidget* _tmp25_ = NULL;
				gint _tmp26_ = 0;
				const gchar* _tmp27_ = NULL;
				gint _tmp28_ = 0;
				gchar* _tmp29_ = NULL;
				gchar* _tmp30_ = NULL;
				gchar* _tmp31_ = NULL;
				gchar* _tmp32_ = NULL;
				BoxesPropertiesPageWidget* _tmp33_ = NULL;
				BoxesPropertiesPageWidget* _tmp34_ = NULL;
				BoxesPropertiesPageWidget* _tmp35_ = NULL;
				BoxesAppWindow* _tmp36_ = NULL;
				BoxesSidebar* _tmp37_ = NULL;
				GtkListStore* _tmp38_ = NULL;
				BoxesPropertiesPageWidget* _tmp39_ = NULL;
				const gchar* _tmp40_ = NULL;
				const gchar* _tmp41_ = NULL;
				BoxesPropertiesPageWidget* _tmp42_ = NULL;
				gboolean _tmp43_ = FALSE;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data48_ = g_slice_new0 (Block48Data);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data48_->_ref_count_ = 1;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data48_->self = g_object_ref (self);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!_tmp19_) {
#line 866 "properties.c"
					gint _tmp20_ = 0;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp20_ = i;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					i = _tmp20_ + 1;
#line 872 "properties.c"
				}
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp19_ = FALSE;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp21_ = i;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!(_tmp21_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					block48_data_unref (_data48_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_data48_ = NULL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					break;
#line 886 "properties.c"
				}
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp22_ = i;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp23_ = machine;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp24_ = boxes_properties_page_widget_new (_tmp22_, _tmp23_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_ref_sink (_tmp24_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data48_->page = _tmp24_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp25_ = _data48_->page;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp26_ = i;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp27_ = BOXES_PROPERTIES_page_names[_tmp26_];
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				gtk_stack_add_named ((GtkStack*) self, (GtkWidget*) _tmp25_, _tmp27_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp28_ = i;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp29_ = g_strdup_printf ("%i", _tmp28_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp30_ = _tmp29_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp31_ = g_strconcat ("boxes-property-", _tmp30_, NULL);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp32_ = _tmp31_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp33_ = _data48_->page;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp34_ = _g_object_ref0 (_tmp33_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_set_data_full ((GObject*) self, _tmp32_, _tmp34_, g_object_unref);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (_tmp32_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (_tmp30_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp35_ = _data48_->page;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_signal_connect_data (_tmp35_, "refresh-properties", (GCallback) ______lambda154__boxes_properties_page_widget_refresh_properties, block48_data_ref (_data48_), (GClosureNotify) block48_data_unref, 0);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp36_ = boxes_app_window;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp37_ = _tmp36_->sidebar;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp38_ = _tmp37_->props_listmodel;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp39_ = _data48_->page;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp40_ = gtk_widget_get_name ((GtkWidget*) _tmp39_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp41_ = _tmp40_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp42_ = _data48_->page;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp43_ = _tmp42_->empty;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_properties_list_append (self, _tmp38_, _tmp41_, !_tmp43_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				block48_data_unref (_data48_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_data48_ = NULL;
#line 952 "properties.c"
			}
		}
	}
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp44_ = libvirt_machine;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp44_ != NULL) {
#line 960 "properties.c"
		BoxesPropertiesPage _tmp45_ = 0;
		BoxesUIState _tmp46_ = 0;
		BoxesUIState _tmp47_ = 0;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp46_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp47_ = _tmp46_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp47_ == BOXES_UI_STATE_WIZARD) {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp45_ = BOXES_PROPERTIES_PAGE_SYSTEM;
#line 972 "properties.c"
		} else {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp45_ = BOXES_PROPERTIES_PAGE_LOGIN;
#line 976 "properties.c"
		}
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		current_page = _tmp45_;
#line 980 "properties.c"
	} else {
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		current_page = BOXES_PROPERTIES_PAGE_LOGIN;
#line 984 "properties.c"
	}
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp48_ = current_page;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp49_ = gtk_tree_path_new_from_indices (_tmp48_, -1);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	path = _tmp49_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp50_ = boxes_app_window;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp51_ = _tmp50_->sidebar;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp52_ = _tmp51_->props_selection;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp53_ = path;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_selection_select_path (_tmp52_, _tmp53_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp54_ = current_page;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp55_ = BOXES_PROPERTIES_page_names[_tmp54_];
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp55_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_gtk_tree_path_free0 (path);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (libvirt_machine);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (machine);
#line 1014 "properties.c"
}


static void boxes_properties_setup_ui (BoxesProperties* self) {
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_stack_set_transition_type ((GtkStack*) self, GTK_STACK_TRANSITION_TYPE_SLIDE_UP_DOWN);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_stack_set_transition_duration ((GtkStack*) self, (guint) 400);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 1027 "properties.c"
}


static Block49Data* block49_data_ref (Block49Data* _data49_) {
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_atomic_int_inc (&_data49_->_ref_count_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return _data49_;
#line 1036 "properties.c"
}


static void block49_data_unref (void * _userdata_) {
	Block49Data* _data49_;
	_data49_ = (Block49Data*) _userdata_;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (g_atomic_int_dec_and_test (&_data49_->_ref_count_)) {
#line 1045 "properties.c"
		BoxesProperties* self;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self = _data49_->self;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (_data49_->libvirt_machine);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (self);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_slice_free (Block49Data, _data49_);
#line 1055 "properties.c"
	}
}


static void ____lambda155_ (Block49Data* _data49_) {
	BoxesProperties* self;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesSidebar* _tmp1_ = NULL;
	BoxesMiniGraph* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	gdouble* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	BoxesAppWindow* _tmp5_ = NULL;
	BoxesSidebar* _tmp6_ = NULL;
	BoxesMiniGraph* _tmp7_ = NULL;
	BoxesLibvirtMachine* _tmp8_ = NULL;
	gdouble* _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	BoxesAppWindow* _tmp10_ = NULL;
	BoxesSidebar* _tmp11_ = NULL;
	BoxesMiniGraph* _tmp12_ = NULL;
	BoxesLibvirtMachine* _tmp13_ = NULL;
	gdouble* _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = _data49_->self;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = boxes_app_window;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _tmp0_->sidebar;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = _tmp1_->cpu_graph;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = _data49_->libvirt_machine;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = _tmp3_->cpu_stats;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4__length1 = _tmp3_->cpu_stats_length1;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_mini_graph_set_points (_tmp2_, _tmp4_, _tmp4__length1);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = boxes_app_window;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = _tmp5_->sidebar;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = _tmp6_->net_graph;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = _data49_->libvirt_machine;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = _tmp8_->net_stats;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9__length1 = _tmp8_->net_stats_length1;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_mini_graph_set_points (_tmp7_, _tmp9_, _tmp9__length1);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = boxes_app_window;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp11_ = _tmp10_->sidebar;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp12_ = _tmp11_->io_graph;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp13_ = _data49_->libvirt_machine;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp14_ = _tmp13_->io_stats;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp14__length1 = _tmp13_->io_stats_length1;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_mini_graph_set_points (_tmp12_, _tmp14_, _tmp14__length1);
#line 1124 "properties.c"
}


static void _____lambda155__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self) {
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	____lambda155_ (self);
#line 1131 "properties.c"
}


static Block50Data* block50_data_ref (Block50Data* _data50_) {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_atomic_int_inc (&_data50_->_ref_count_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return _data50_;
#line 1140 "properties.c"
}


static void block50_data_unref (void * _userdata_) {
	Block50Data* _data50_;
	_data50_ = (Block50Data*) _userdata_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (g_atomic_int_dec_and_test (&_data50_->_ref_count_)) {
#line 1149 "properties.c"
		BoxesProperties* self;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self = _data50_->self;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (_data50_->machine);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (self);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_slice_free (Block50Data, _data50_);
#line 1159 "properties.c"
	}
}


static void _____lambda156_ (Block50Data* _data50_) {
	BoxesProperties* self;
	BoxesMachine* _tmp0_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = _data50_->self;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = _data50_->machine;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_machine_restart (_tmp0_);
#line 1173 "properties.c"
}


static void ______lambda156__boxes_notification_ok_func (gpointer self) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda156_ (self);
#line 1180 "properties.c"
}


static void boxes_properties_ui_state_changed (BoxesProperties* self) {
	gulong _tmp0_ = 0UL;
	BoxesUIState _tmp4_ = 0;
	BoxesUIState _tmp5_ = 0;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->stats_id;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 1194 "properties.c"
		BoxesApp* _tmp1_ = NULL;
		BoxesCollectionItem* _tmp2_ = NULL;
		gulong _tmp3_ = 0UL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp1_ = boxes_app_app;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp2_ = _tmp1_->current_item;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp3_ = self->priv->stats_id;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_signal_handler_disconnect ((GObject*) _tmp2_, _tmp3_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self->priv->stats_id = (gulong) 0;
#line 1208 "properties.c"
	}
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = _tmp4_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp5_ == BOXES_UI_STATE_PROPERTIES) {
#line 1216 "properties.c"
		gboolean _tmp6_ = FALSE;
		BoxesUIState _tmp7_ = 0;
		BoxesUIState _tmp8_ = 0;
		BoxesAppWindow* _tmp12_ = NULL;
		BoxesApp* _tmp13_ = NULL;
		BoxesCollectionItem* _tmp14_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp7_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp8_ = _tmp7_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp8_ == BOXES_UI_STATE_DISPLAY) {
#line 1229 "properties.c"
			BoxesAppWindow* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			gboolean _tmp11_ = FALSE;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp9_ = boxes_app_window;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp10_ = boxes_app_window_get_fullscreened (_tmp9_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp11_ = _tmp10_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp6_ = _tmp11_;
#line 1241 "properties.c"
		} else {
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp6_ = FALSE;
#line 1245 "properties.c"
		}
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self->priv->restore_fullscreen = _tmp6_;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp12_ = boxes_app_window;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_app_window_set_fullscreened (_tmp12_, FALSE);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp13_ = boxes_app_app;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp14_ = _tmp13_->current_item;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 1259 "properties.c"
			Block49Data* _data49_;
			BoxesApp* _tmp15_ = NULL;
			BoxesCollectionItem* _tmp16_ = NULL;
			BoxesLibvirtMachine* _tmp17_ = NULL;
			BoxesLibvirtMachine* _tmp18_ = NULL;
			gulong _tmp19_ = 0UL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_ = g_slice_new0 (Block49Data);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_->_ref_count_ = 1;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_->self = g_object_ref (self);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp15_ = boxes_app_app;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp16_ = _tmp15_->current_item;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp16_) : NULL);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_->libvirt_machine = _tmp17_;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp18_ = _data49_->libvirt_machine;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp19_ = g_signal_connect_data (_tmp18_, "stats-updated", (GCallback) _____lambda155__boxes_libvirt_machine_stats_updated, block49_data_ref (_data49_), (GClosureNotify) block49_data_unref, 0);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			self->priv->stats_id = _tmp19_;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			block49_data_unref (_data49_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data49_ = NULL;
#line 1290 "properties.c"
		}
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_properties_populate (self);
#line 1294 "properties.c"
	} else {
		BoxesUIState _tmp20_ = 0;
		BoxesUIState _tmp21_ = 0;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp20_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp21_ = _tmp20_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp21_ == BOXES_UI_STATE_PROPERTIES) {
#line 1304 "properties.c"
			Block50Data* _data50_;
			gboolean reboot_required = FALSE;
			BoxesApp* _tmp36_ = NULL;
			BoxesCollectionItem* _tmp37_ = NULL;
			BoxesMachine* _tmp38_ = NULL;
			gboolean _tmp39_ = FALSE;
			gboolean _tmp40_ = FALSE;
			gboolean _tmp58_ = FALSE;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_ = g_slice_new0 (Block50Data);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_->_ref_count_ = 1;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_->self = g_object_ref (self);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			reboot_required = FALSE;
#line 1321 "properties.c"
			{
				gint i = 0;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				i = 0;
#line 1326 "properties.c"
				{
					gboolean _tmp22_ = FALSE;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp22_ = TRUE;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					while (TRUE) {
#line 1333 "properties.c"
						gint _tmp24_ = 0;
						BoxesPropertiesPageWidget* page = NULL;
						gint _tmp25_ = 0;
						gchar* _tmp26_ = NULL;
						gchar* _tmp27_ = NULL;
						gchar* _tmp28_ = NULL;
						gchar* _tmp29_ = NULL;
						gconstpointer _tmp30_ = NULL;
						BoxesPropertiesPageWidget* _tmp31_ = NULL;
						BoxesPropertiesPageWidget* _tmp32_ = NULL;
						gboolean _tmp33_ = FALSE;
						BoxesPropertiesPageWidget* _tmp34_ = NULL;
						gboolean _tmp35_ = FALSE;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						if (!_tmp22_) {
#line 1349 "properties.c"
							gint _tmp23_ = 0;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							_tmp23_ = i;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							i = _tmp23_ + 1;
#line 1355 "properties.c"
						}
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp22_ = FALSE;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp24_ = i;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						if (!(_tmp24_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							break;
#line 1365 "properties.c"
						}
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp25_ = i;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp26_ = g_strdup_printf ("%i", _tmp25_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp27_ = _tmp26_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp28_ = g_strconcat ("boxes-property-", _tmp27_, NULL);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp29_ = _tmp28_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp30_ = g_object_get_data ((GObject*) self, _tmp29_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp31_ = _g_object_ref0 ((BoxesPropertiesPageWidget*) _tmp30_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp32_ = _tmp31_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_free0 (_tmp29_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_free0 (_tmp27_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						page = _tmp32_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp33_ = reboot_required;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp34_ = page;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp35_ = boxes_properties_page_widget_flush_changes (_tmp34_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						reboot_required = _tmp33_ | _tmp35_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (page);
#line 1399 "properties.c"
					}
				}
			}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp36_ = boxes_app_app;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp37_ = _tmp36_->current_item;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp38_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp37_) : NULL);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_->machine = _tmp38_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp40_ = reboot_required;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp40_) {
#line 1415 "properties.c"
				gboolean _tmp41_ = FALSE;
				BoxesMachine* _tmp42_ = NULL;
				gboolean _tmp43_ = FALSE;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp42_ = _data50_->machine;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp43_ = boxes_machine_is_on (_tmp42_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (_tmp43_) {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp41_ = TRUE;
#line 1427 "properties.c"
				} else {
					BoxesMachine* _tmp44_ = NULL;
					BoxesMachineMachineState _tmp45_ = 0;
					BoxesMachineMachineState _tmp46_ = 0;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp44_ = _data50_->machine;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp45_ = boxes_machine_get_state (_tmp44_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp46_ = _tmp45_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp41_ = _tmp46_ == BOXES_MACHINE_MACHINE_STATE_SAVED;
#line 1440 "properties.c"
				}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp39_ = _tmp41_;
#line 1444 "properties.c"
			} else {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp39_ = FALSE;
#line 1448 "properties.c"
			}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp39_) {
#line 1452 "properties.c"
				gchar* message = NULL;
				const gchar* _tmp47_ = NULL;
				BoxesMachine* _tmp48_ = NULL;
				const gchar* _tmp49_ = NULL;
				const gchar* _tmp50_ = NULL;
				gchar* _tmp51_ = NULL;
				BoxesAppWindow* _tmp52_ = NULL;
				BoxesNotificationbar* _tmp53_ = NULL;
				const gchar* _tmp54_ = NULL;
				const gchar* _tmp55_ = NULL;
				GdNotification* _tmp56_ = NULL;
				GdNotification* _tmp57_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp47_ = _ ("Changes require restart of '%s'.");
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp48_ = _data50_->machine;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp49_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp48_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp50_ = _tmp49_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp51_ = g_strdup_printf (_tmp47_, _tmp50_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				message = _tmp51_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp52_ = boxes_app_window;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp53_ = _tmp52_->notificationbar;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp54_ = message;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp55_ = _ ("_Restart");
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp56_ = boxes_notificationbar_display_for_action (_tmp53_, _tmp54_, _tmp55_, ______lambda156__boxes_notification_ok_func, block50_data_ref (_data50_), block50_data_unref, NULL, NULL, NULL, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp57_ = _tmp56_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (_tmp57_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (message);
#line 1493 "properties.c"
			}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp58_ = self->priv->restore_fullscreen;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp58_) {
#line 1499 "properties.c"
				BoxesAppWindow* _tmp59_ = NULL;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp59_ = boxes_app_window;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_app_window_set_fullscreened (_tmp59_, TRUE);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				self->priv->restore_fullscreen = FALSE;
#line 1507 "properties.c"
			}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			block50_data_unref (_data50_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_ = NULL;
#line 1513 "properties.c"
		}
	}
}


BoxesProperties* boxes_properties_construct (GType object_type) {
	BoxesProperties * self = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) g_object_new (object_type, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self;
#line 1525 "properties.c"
}


BoxesProperties* boxes_properties_new (void) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return boxes_properties_construct (BOXES_TYPE_PROPERTIES);
#line 1532 "properties.c"
}


static BoxesUIState boxes_properties_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 1548 "properties.c"
}


static void boxes_properties_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = value;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 1563 "properties.c"
}


static BoxesUIState boxes_properties_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->_ui_state;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 1579 "properties.c"
}


static void boxes_properties_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->_ui_state = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 1594 "properties.c"
}


BoxesPropertiesPage boxes_properties_get_page (BoxesProperties* self) {
	BoxesPropertiesPage result;
	BoxesPropertiesPage _tmp0_ = 0;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->_page;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = _tmp0_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 1609 "properties.c"
}


void boxes_properties_set_page (BoxesProperties* self, BoxesPropertiesPage value) {
	BoxesPropertiesPage _tmp0_ = 0;
	BoxesPropertiesPage _tmp1_ = 0;
	const gchar* _tmp2_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = value;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->_page = _tmp0_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = value;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = BOXES_PROPERTIES_page_names[_tmp1_];
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp2_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_notify ((GObject *) self, "page");
#line 1631 "properties.c"
}


static void _boxes_properties_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_ui_state_changed ((BoxesProperties*) self);
#line 1638 "properties.c"
}


static GObject * boxes_properties_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesProperties * self;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	parent_class = G_OBJECT_CLASS (boxes_properties_parent_class);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_properties_ui_state_changed_g_object_notify, self, 0);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_setup_ui (self);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return obj;
#line 1658 "properties.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1665 "properties.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_list_free (self);
#line 1674 "properties.c"
}


static void _____lambda153_ (BoxesPropertiesPageWidget* self) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_emit_by_name (self, "refresh-properties");
#line 1681 "properties.c"
}


static void ______lambda153__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda153_ ((BoxesPropertiesPageWidget*) self);
#line 1688 "properties.c"
}


static BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine) {
	BoxesPropertiesPageWidget * self = NULL;
	BoxesPropertiesPage _tmp0_ = 0;
	GtkStyleContext* _tmp5_ = NULL;
	GtkStyleContext* _tmp6_ = NULL;
	GtkGrid* _tmp7_ = NULL;
	GtkGrid* _tmp8_ = NULL;
	GtkGrid* _tmp9_ = NULL;
	GtkGrid* _tmp10_ = NULL;
	GtkGrid* _tmp11_ = NULL;
	GtkGrid* _tmp12_ = NULL;
	PropertyCreationFlag flags = 0;
	BoxesMachine* _tmp13_ = NULL;
	BoxesPropertiesPage _tmp14_ = 0;
	GList* _tmp15_ = NULL;
	GList* _tmp16_ = NULL;
	guint _tmp17_ = 0U;
	gboolean _tmp18_ = FALSE;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesPropertiesPageWidget*) g_object_new (object_type, NULL);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = page;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (_tmp0_) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_LOGIN:
#line 1720 "properties.c"
		{
			const gchar* _tmp1_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp1_ = _ ("Login");
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp1_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 1729 "properties.c"
		}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 1733 "properties.c"
		{
			const gchar* _tmp2_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp2_ = _ ("System");
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp2_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 1742 "properties.c"
		}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_DISPLAY:
#line 1746 "properties.c"
		{
			const gchar* _tmp3_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp3_ = _ ("Display");
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp3_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 1755 "properties.c"
		}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 1759 "properties.c"
		{
			const gchar* _tmp4_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp4_ = _ ("Devices");
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			gtk_widget_set_name ((GtkWidget*) self, _tmp4_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 1768 "properties.c"
		}
		default:
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 1773 "properties.c"
	}
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp5_, "properties");
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp6_, "boxes-bg");
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = (GtkGrid*) gtk_grid_new ();
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp7_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->grid);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->grid = _tmp7_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = self->priv->grid;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_set ((GtkWidget*) _tmp8_, "margin", 20, NULL);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = self->priv->grid;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_set_row_spacing (_tmp9_, 10);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = self->priv->grid;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_set_column_spacing (_tmp10_, 20);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp11_ = self->priv->grid;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp11_, GTK_ALIGN_START);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp12_ = self->priv->grid;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_box_pack_end ((GtkBox*) self, (GtkWidget*) _tmp12_, TRUE, TRUE, (guint) 0);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	flags = PROPERTY_CREATION_FLAG_NONE;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp13_ = machine;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp14_ = page;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp15_ = boxes_machine_get_properties (_tmp13_, _tmp14_, &flags);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->properties = _tmp15_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp16_ = self->priv->properties;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp17_ = g_list_length (_tmp16_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->empty = _tmp17_ == ((guint) 0);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp18_ = self->empty;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (!_tmp18_) {
#line 1833 "properties.c"
		gint current_row = 0;
		GList* _tmp19_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		current_row = 1;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp19_ = self->priv->properties;
#line 1840 "properties.c"
		{
			GList* property_collection = NULL;
			GList* property_it = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			property_collection = _tmp19_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 1848 "properties.c"
				BoxesProperty* _tmp20_ = NULL;
				BoxesProperty* property = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp20_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				property = _tmp20_;
#line 1855 "properties.c"
				{
					BoxesProperty* _tmp21_ = NULL;
					const gchar* _tmp22_ = NULL;
					const gchar* _tmp23_ = NULL;
					GtkWidget* widget = NULL;
					BoxesProperty* _tmp53_ = NULL;
					GtkWidget* _tmp54_ = NULL;
					GtkWidget* _tmp55_ = NULL;
					GtkWidget* _tmp56_ = NULL;
					GtkWidget* _tmp57_ = NULL;
					BoxesProperty* _tmp64_ = NULL;
					gint _tmp65_ = 0;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp21_ = property;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp22_ = boxes_property_get_description (_tmp21_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp23_ = _tmp22_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					if (_tmp23_ != NULL) {
#line 1876 "properties.c"
						GtkLabel* label_name = NULL;
						BoxesProperty* _tmp24_ = NULL;
						const gchar* _tmp25_ = NULL;
						const gchar* _tmp26_ = NULL;
						GtkLabel* _tmp27_ = NULL;
						GtkLabel* _tmp28_ = NULL;
						GtkStyleContext* _tmp29_ = NULL;
						GtkLabel* _tmp30_ = NULL;
						GtkLabel* _tmp31_ = NULL;
						GtkLabel* _tmp32_ = NULL;
						GtkGrid* _tmp33_ = NULL;
						GtkLabel* _tmp34_ = NULL;
						gint _tmp35_ = 0;
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp36_ = NULL;
						GtkWidget* _tmp37_ = NULL;
						GtkWidget* _tmp38_ = NULL;
						GtkWidget* _tmp39_ = NULL;
						GtkWidget* _tmp40_ = NULL;
						GtkGrid* _tmp41_ = NULL;
						GtkWidget* _tmp42_ = NULL;
						gint _tmp43_ = 0;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp24_ = property;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp25_ = boxes_property_get_description (_tmp24_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp26_ = _tmp25_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp27_ = (GtkLabel*) gtk_label_new (_tmp26_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						g_object_ref_sink (_tmp27_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						label_name = _tmp27_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp28_ = label_name;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp29_ = gtk_widget_get_style_context ((GtkWidget*) _tmp28_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_style_context_add_class (_tmp29_, "boxes-property-name-label");
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp30_ = label_name;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_margin_left ((GtkWidget*) _tmp30_, 25);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp31_ = label_name;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_halign ((GtkWidget*) _tmp31_, GTK_ALIGN_START);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp32_ = label_name;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand ((GtkWidget*) _tmp32_, FALSE);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp33_ = self->priv->grid;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp34_ = label_name;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp35_ = current_row;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach (_tmp33_, (GtkWidget*) _tmp34_, 0, _tmp35_, 1, 1);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp36_ = property;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp37_ = boxes_property_get_widget (_tmp36_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp38_ = _tmp37_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp39_ = _g_object_ref0 (_tmp38_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						widget = _tmp39_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp40_ = widget;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand (_tmp40_, TRUE);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp41_ = self->priv->grid;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp42_ = widget;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp43_ = current_row;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach (_tmp41_, _tmp42_, 1, _tmp43_, 1, 1);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (widget);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (label_name);
#line 1963 "properties.c"
					} else {
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp44_ = NULL;
						GtkWidget* _tmp45_ = NULL;
						GtkWidget* _tmp46_ = NULL;
						GtkWidget* _tmp47_ = NULL;
						GtkWidget* _tmp48_ = NULL;
						GtkWidget* _tmp49_ = NULL;
						GtkGrid* _tmp50_ = NULL;
						GtkWidget* _tmp51_ = NULL;
						gint _tmp52_ = 0;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp44_ = property;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp45_ = boxes_property_get_widget (_tmp44_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp46_ = _tmp45_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp47_ = _g_object_ref0 (_tmp46_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						widget = _tmp47_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp48_ = widget;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand (_tmp48_, TRUE);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp49_ = widget;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_margin_left (_tmp49_, 25);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp50_ = self->priv->grid;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp51_ = widget;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp52_ = current_row;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach (_tmp50_, _tmp51_, 0, _tmp52_, 2, 1);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (widget);
#line 2003 "properties.c"
					}
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp53_ = property;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp54_ = boxes_property_get_extra_widget (_tmp53_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp55_ = _tmp54_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp56_ = _g_object_ref0 (_tmp55_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					widget = _tmp56_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp57_ = widget;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					if (_tmp57_ != NULL) {
#line 2019 "properties.c"
						gint _tmp58_ = 0;
						GtkWidget* _tmp59_ = NULL;
						GtkWidget* _tmp60_ = NULL;
						GtkGrid* _tmp61_ = NULL;
						GtkWidget* _tmp62_ = NULL;
						gint _tmp63_ = 0;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp58_ = current_row;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						current_row = _tmp58_ + 1;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp59_ = widget;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_margin_left (_tmp59_, 25);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp60_ = widget;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand (_tmp60_, TRUE);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp61_ = self->priv->grid;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp62_ = widget;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp63_ = current_row;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach (_tmp61_, _tmp62_, 0, _tmp63_, 2, 1);
#line 2046 "properties.c"
					}
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp64_ = property;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					g_signal_connect_object (_tmp64_, "refresh-properties", (GCallback) ______lambda153__boxes_property_refresh_properties, self, 0);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp65_ = current_row;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					current_row = _tmp65_ + 1;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_g_object_unref0 (widget);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_g_object_unref0 (property);
#line 2060 "properties.c"
				}
			}
		}
	}
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self;
#line 2069 "properties.c"
}


static BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return boxes_properties_page_widget_construct (BOXES_PROPERTIES_TYPE_PAGE_WIDGET, page, machine);
#line 2076 "properties.c"
}


static gboolean boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self) {
	gboolean result = FALSE;
	gboolean reboot_required = FALSE;
	GList* _tmp0_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	reboot_required = FALSE;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->properties;
#line 2090 "properties.c"
	{
		GList* property_collection = NULL;
		GList* property_it = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		property_collection = _tmp0_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 2098 "properties.c"
			BoxesProperty* _tmp1_ = NULL;
			BoxesProperty* property = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp1_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			property = _tmp1_;
#line 2105 "properties.c"
			{
				BoxesProperty* _tmp2_ = NULL;
				gboolean _tmp3_ = FALSE;
				BoxesProperty* _tmp4_ = NULL;
				gboolean _tmp5_ = FALSE;
				gboolean _tmp6_ = FALSE;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp2_ = property;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_property_flush (_tmp2_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp3_ = reboot_required;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp4_ = property;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp5_ = boxes_property_get_reboot_required (_tmp4_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp6_ = _tmp5_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				reboot_required = _tmp3_ | _tmp6_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (property);
#line 2128 "properties.c"
			}
		}
	}
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = reboot_required;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 2136 "properties.c"
}


static void boxes_properties_page_widget_class_init (BoxesPropertiesPageWidgetClass * klass) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_page_widget_parent_class = g_type_class_peek_parent (klass);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPageWidgetPrivate));
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_page_widget_finalize;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_new ("refresh_properties", BOXES_PROPERTIES_TYPE_PAGE_WIDGET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 2149 "properties.c"
}


static void boxes_properties_page_widget_instance_init (BoxesPropertiesPageWidget * self) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv = BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE (self);
#line 2156 "properties.c"
}


static void boxes_properties_page_widget_finalize (GObject* obj) {
	BoxesPropertiesPageWidget * self;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidget);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->grid);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (boxes_properties_page_widget_parent_class)->finalize (obj);
#line 2170 "properties.c"
}


static GType boxes_properties_page_widget_get_type (void) {
	static volatile gsize boxes_properties_page_widget_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_widget_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesPageWidgetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_page_widget_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPropertiesPageWidget), 0, (GInstanceInitFunc) boxes_properties_page_widget_instance_init, NULL };
		GType boxes_properties_page_widget_type_id;
		boxes_properties_page_widget_type_id = g_type_register_static (GTK_TYPE_BOX, "BoxesPropertiesPageWidget", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_page_widget_type_id__volatile, boxes_properties_page_widget_type_id);
	}
	return boxes_properties_page_widget_type_id__volatile;
}


static void boxes_properties_class_init (BoxesPropertiesClass * klass) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPrivate));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_properties_get_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_properties_set_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_properties_constructor;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_finalize;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_PAGE, g_param_spec_enum ("page", "page", "page", BOXES_TYPE_PROPERTIES_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2205 "properties.c"
}


static void boxes_properties_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->get_previous_ui_state = boxes_properties_real_get_previous_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->set_previous_ui_state = boxes_properties_real_set_previous_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->get_ui_state = boxes_properties_real_get_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->set_ui_state = boxes_properties_real_set_ui_state;
#line 2220 "properties.c"
}


static void boxes_properties_instance_init (BoxesProperties * self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv = BOXES_PROPERTIES_GET_PRIVATE (self);
#line 2227 "properties.c"
}


static void boxes_properties_finalize (GObject* obj) {
	BoxesProperties * self;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (boxes_properties_parent_class)->finalize (obj);
#line 2237 "properties.c"
}


GType boxes_properties_get_type (void) {
	static volatile gsize boxes_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesProperties), 0, (GInstanceInitFunc) boxes_properties_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_properties_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_properties_type_id;
		boxes_properties_type_id = g_type_register_static (GTK_TYPE_STACK, "BoxesProperties", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_properties_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_properties_type_id__volatile, boxes_properties_type_id);
	}
	return boxes_properties_type_id__volatile;
}


static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PREVIOUS_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_value_set_enum (value, boxes_properties_get_page (self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2278 "properties.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2284 "properties.c"
	}
}


static void _vala_boxes_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PREVIOUS_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_properties_set_page (self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2312 "properties.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2318 "properties.c"
	}
}



